couchdb.schema.Schema

Package couchdb :: Module schema :: Class Schema |

# Class Schema

    object --+
             |
            Schema

Known Subclasses:
  - Document

Nested Classes
| __metaclass__

Instance Methods
__init__(self, **values) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__iter__(self) |
__len__(self) |
__delitem__(self, name) |
__getitem__(self, name) |
__setitem__(self, name, value) |
get(self, name, default) |
setdefault(self, name, default) |
unwrap(self) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods
build(cls, **d) |
wrap(cls, data) |

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, **values) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)